module Phylo.Data where

import Prelude

import Affjax as AX
import Affjax.ResponseFormat as ResponseFormat
import Data.Either (Either(..))
import Data.HTTP.Method (Method(..))
import Data.Maybe (Maybe)
import Effect (Effect)
import Effect.Aff (launchAff_)
import Effect.Class.Console (log)
import Simple.JSON as JSON
import App as App

type PhyloJSON =
  { name :: String
  , phyloDocs :: String
  , phyloFoundations :: String
  , phyloPeriods :: String
  , phyloTerms :: String
  , phyloGroups :: String
  , phyloBranches :: String
  , objects :: Array  { name     :: String
                      , nodeType :: Maybe String 
                      }
  }

main :: Effect Unit
main = 
  launchAff_
    $ do
    result <- AX.request (AX.defaultRequest { url = "http://localhost:5501/data/knowledge-phylomemy.json", method = Left GET, responseFormat = ResponseFormat.string })
    case result of
      Left err -> log $ "Phylo failed to load error : " <> AX.printError err
      Right response -> do
        case JSON.readJSON response.body of
          Left err -> log $ "Fail with error: " <> show err
          Right (r :: PhyloJSON) -> do
            log $ "name of phylo is : " <> show r.name
            log $ "number of docs is : " <> show r.phyloDocs
            log $ "number of foundations is : " <> show r.phyloFoundations
            log $ "number of periods is : " <> show r.phyloPeriods
            log $ "number of terms is : " <> show r.phyloTerms
            log $ "number of groups is : " <> show r.phyloGroups
            log $ "number of branches is : " <> show r.phyloBranches
            log $ "objects are : " <> show r.objects
